//
// "$Id: Fl_Positioner.H,v 1.5.2.3.2.2.2.4 2004/03/18 08:00:35 matthiaswm Exp $"
//
// Positioner header file for the Fast Light Tool Kit (FLTK).
//
// Copyright 1998-2004 by Bill Spitzak and others.
//
// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Library General Public
// License as published by the Free Software Foundation; either
// version 2 of the License, or (at your option) any later version.
//
// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Library General Public License for more details.
//
// You should have received a copy of the GNU Library General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
// USA.
//
// Please report all bugs and problems to "fltk-bugs@fltk.org".
//

#ifndef Fl_Positioner_H
#define Fl_Positioner_H

#ifndef Fl_Widget_H
#include "Fl_Widget.H"
#endif

/** This class is provided for Forms compatibility. It provides 2D input. 
 * It would be useful if this could be put atop another widget so that the
 * crosshairs are on top, but this is not implemented. The color of the
 * crosshairs is selection_color().
 *   \image html positioner.gif
 */
class FL_EXPORT Fl_Positioner : public Fl_Widget {

  double xmin, ymin;
  double xmax, ymax;
  double xvalue_, yvalue_;
  double xstep_, ystep_;

protected:

  // these allow subclasses to put the dial in a smaller area:
  void draw(int, int, int, int);
  int handle(int, int, int, int, int);
  void draw();

public:

  int handle(int event);
    /** Creates a new Fl_Positioner widget using the given position, 
     * size, and label string. The default boxtype is \c FL_NO_BOX. */
  Fl_Positioner(int x,int y,int w,int h, const char *l=0);
    /** Returns the X axis coordinate */
  double xvalue() const {return xvalue_;}
    /** Returns the Y axis coordinate */
  double yvalue() const {return yvalue_;}
    /** Sets the X axis coordinate */
  int xvalue(double x); 
    /** Sets the Y axis coordinate */
  int yvalue(double y);
    /** Sets the X an Y axis vaules */
  int value(double x,double y);
    /** Sets the X axis bounds */
  void xbounds(double min, double max);
    /** Returns the X axis minimum bound */
  double xminimum() const {return xmin;}
    /** Sets the X axis minimum bound */
  void xminimum(double a) {xbounds(a,xmax);}
    /** Returns the X axis maximum bound */
  double xmaximum() const {return xmax;}
    /** Sets the X axis maximum bound */
  void xmaximum(double a) {xbounds(xmin,a);}
    /** Sets the Y axis bounds */
  void ybounds(double, double);
    /** Returns the Y axis minimum bound */
  double yminimum() const {return ymin;}
    /** Sets the Y axis minimum bound */
  void yminimum(double a) {ybounds(a,ymax);}
    /** Returns the Y axis maximum bound */
  double ymaximum() const {return ymax;}
    /** Sets the Y axis maximum bound */
  void ymaximum(double a) {ybounds(ymin,a);}
    /** Sets teh stepping value for the X axis */
  void xstep(double a) {xstep_ = a;}
    /** Sets teh stepping value for the Y axis */
  void ystep(double a) {ystep_ = a;}

};

#endif

//
// End of "$Id: Fl_Positioner.H,v 1.5.2.3.2.2.2.4 2004/03/18 08:00:35 matthiaswm Exp $".
//
